@@ -1,8 +1,6 @@
-# Copyright 1999-2018 Gentoo Foundation
+# Copyright 1999-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import unicode_literals
-
 import functools
 import sys
 from itertools import chain
@@ -21,13 +19,6 @@ from portage.exception import InvalidData, InvalidDependString
 from portage.localization import _
 from _emerge.Task import Task
 
-if sys.hexversion >= 0x3000000:
-	basestring = str
-	long = int
-	_unicode = str
-else:
-	_unicode = unicode
-
 class Package(Task):
 
 	__hash__ = Task.__hash__
@@ -222,7 +213,7 @@ class Package(Task):
 		else:
 			raise TypeError("root_config argument is required")
 
-		elements = [type_name, root, _unicode(cpv), operation]
+		elements = [type_name, root, str(cpv), operation]
 
 		# For installed (and binary) packages we don't care for the repo
 		# when it comes to hashing, because there can only be one cpv.
@@ -515,7 +506,7 @@ class Package(Task):
 			cpv_color = "PKG_NOMERGE"
 
 		build_id_str = ""
-		if isinstance(self.cpv.build_id, long) and self.cpv.build_id > 0:
+		if isinstance(self.cpv.build_id, int) and self.cpv.build_id > 0:
 			build_id_str = "-%s" % self.cpv.build_id
 
 		s = "(%s, %s" \
@@ -537,14 +528,6 @@ class Package(Task):
 		s += ")"
 		return s
 
-	if sys.hexversion < 0x3000000:
-
-		__unicode__ = __str__
-
-		def __str__(self):
-			return _unicode_encode(self.__unicode__(),
-				encoding=_encodings['content'])
-
 	class _use_class(object):
 
 		__slots__ = ("enabled", "_expand", "_expand_hidden",
@@ -714,7 +697,7 @@ class Package(Task):
 			@return: True if all flags are valid USE values which may
 				be specified in USE dependencies, False otherwise.
 			"""
-			if isinstance(flags, basestring):
+			if isinstance(flags, str):
 				flags = [flags]
 
 			for flag in flags:
@@ -727,7 +710,7 @@ class Package(Task):
 			"""
 			@return: A list of flags missing from IUSE.
 			"""
-			if isinstance(flags, basestring):
+			if isinstance(flags, str):
 				flags = [flags]
 			missing_iuse = []
 			for flag in flags:
@@ -873,14 +856,14 @@ class _PackageMetadataWrapper(_PackageMetadataWrapperBase):
 			getattr(self, "_set_" + k.lower())(k, v)
 
 	def _set_inherited(self, k, v):
-		if isinstance(v, basestring):
+		if isinstance(v, str):
 			v = frozenset(v.split())
 		self._pkg.inherited = v
 
 	def _set_counter(self, k, v):
-		if isinstance(v, basestring):
+		if isinstance(v, str):
 			try:
-				v = long(v.strip())
+				v = int(v.strip())
 			except ValueError:
 				v = 0
 		self._pkg.counter = v
@@ -898,9 +881,9 @@ class _PackageMetadataWrapper(_PackageMetadataWrapperBase):
 				pass
 
 	def _set__mtime_(self, k, v):
-		if isinstance(v, basestring):
+		if isinstance(v, str):
 			try:
-				v = long(v.strip())
+				v = int(v.strip())
 			except ValueError:
 				v = 0
 		self._pkg.mtime = v
