@@ -42,11 +42,6 @@ class TaskSequence(CompositeTask):
 
 		self._start_task(task, self._task_exit_handler)
 
-	def _current_task_start_cb(self, future):
-		CompositeTask._current_task_start_cb(self, future)
-		if self.cancelled:
-			self._task_queue.clear()
-
 	def _task_exit_handler(self, task):
 		if self._default_exit(task) != os.EX_OK:
 			self.wait()
@@ -59,8 +54,5 @@ class TaskSequence(CompositeTask):
 	def __bool__(self):
 		return bool(self._task_queue)
 
-	if sys.hexversion < 0x3000000:
-		__nonzero__ = __bool__
-
 	def __len__(self):
 		return len(self._task_queue)
