@@ -1,8 +1,6 @@
-# Copyright 1998-2019 Gentoo Authors
+# Copyright 1998-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import unicode_literals
-
 VERSION = "HEAD"
 
 # ===========================================================================
@@ -135,10 +133,6 @@ except ImportError as e:
 	sys.stderr.write("    "+str(e)+"\n\n")
 	raise
 
-if sys.hexversion >= 0x3000000:
-	# pylint: disable=W0622
-	basestring = str
-	long = int
 
 # We use utf_8 encoding everywhere. Previously, we used
 # sys.getfilesystemencoding() for the 'merge' encoding, but that had
@@ -169,43 +163,30 @@ _encodings = {
 	'stdio'                  : 'utf_8',
 }
 
-if sys.hexversion >= 0x3000000:
 
-	def _decode_argv(argv):
-		# With Python 3, the surrogateescape encoding error handler makes it
-		# possible to access the original argv bytes, which can be useful
-		# if their actual encoding does no match the filesystem encoding.
-		fs_encoding = sys.getfilesystemencoding()
-		return [_unicode_decode(x.encode(fs_encoding, 'surrogateescape'))
-			for x in argv]
+def _decode_argv(argv):
+	# With Python 3, the surrogateescape encoding error handler makes it
+	# possible to access the original argv bytes, which can be useful
+	# if their actual encoding does no match the filesystem encoding.
+	fs_encoding = sys.getfilesystemencoding()
+	return [_unicode_decode(x.encode(fs_encoding, 'surrogateescape'))
+		for x in argv]
 
-	def _unicode_encode(s, encoding=_encodings['content'], errors='backslashreplace'):
-		if isinstance(s, str):
-			s = s.encode(encoding, errors)
-		return s
 
-	def _unicode_decode(s, encoding=_encodings['content'], errors='replace'):
-		if isinstance(s, bytes):
-			s = str(s, encoding=encoding, errors=errors)
-		return s
+def _unicode_encode(s, encoding=_encodings['content'], errors='backslashreplace'):
+	if isinstance(s, str):
+		s = s.encode(encoding, errors)
+	return s
 
-	_native_string = _unicode_decode
-else:
 
-	def _decode_argv(argv):
-		return [_unicode_decode(x) for x in argv]
+def _unicode_decode(s, encoding=_encodings['content'], errors='replace'):
+	if isinstance(s, bytes):
+		s = str(s, encoding=encoding, errors=errors)
+	return s
 
-	def _unicode_encode(s, encoding=_encodings['content'], errors='backslashreplace'):
-		if isinstance(s, unicode):
-			s = s.encode(encoding, errors)
-		return s
 
-	def _unicode_decode(s, encoding=_encodings['content'], errors='replace'):
-		if isinstance(s, bytes):
-			s = unicode(s, encoding=encoding, errors=errors)
-		return s
+_native_string = _unicode_decode
 
-	_native_string = _unicode_encode
 
 class _unicode_func_wrapper(object):
 	"""
@@ -469,7 +450,6 @@ _deprecated_eapis = frozenset([
 	"3_pre1",
 	"5_pre1",
 	"5_pre2",
-	"5-hdepend",
 	"6_pre1",
 	"7_pre1",
 ])
@@ -479,7 +459,7 @@ def _eapi_is_deprecated(eapi):
 	return eapi in _deprecated_eapis
 
 def eapi_is_supported(eapi):
-	if not isinstance(eapi, basestring):
+	if not isinstance(eapi, str):
 		# Only call str() when necessary since with python2 it
 		# can trigger UnicodeEncodeError if EAPI is corrupt.
 		eapi = str(eapi)
@@ -518,7 +498,7 @@ auxdbkeys = (
 	'RESTRICT',  'HOMEPAGE',  'LICENSE',   'DESCRIPTION',
 	'KEYWORDS',  'INHERITED', 'IUSE', 'REQUIRED_USE',
 	'PDEPEND',   'BDEPEND', 'EAPI',
-	'PROPERTIES', 'DEFINED_PHASES', 'HDEPEND', 'UNUSED_04',
+	'PROPERTIES', 'DEFINED_PHASES', 'UNUSED_05', 'UNUSED_04',
 	'UNUSED_03', 'UNUSED_02', 'UNUSED_01',
 )
 auxdbkeylen = len(auxdbkeys)
@@ -620,10 +600,10 @@ if VERSION == 'HEAD':
 								head_timestamp = None
 								if len(output_lines) > 3:
 									try:
-										head_timestamp = long(output_lines[3])
+										head_timestamp = int(output_lines[3])
 									except ValueError:
 										pass
-								timestamp = long(time.time())
+								timestamp = int(time.time())
 								if head_timestamp is not None and timestamp > head_timestamp:
 									timestamp = timestamp - head_timestamp
 								if not patchlevel:
