@@ -1,8 +1,6 @@
-# Copyright 1998-2019 Gentoo Authors
+# Copyright 1998-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import unicode_literals
-
 __all__ = ["bindbapi", "binarytree"]
 
 import portage
@@ -54,18 +52,8 @@ import traceback
 import warnings
 from gzip import GzipFile
 from itertools import chain
-try:
-	from urllib.parse import urlparse
-except ImportError:
-	from urlparse import urlparse
+from urllib.parse import urlparse
 
-if sys.hexversion >= 0x3000000:
-	# pylint: disable=W0622
-	_unicode = str
-	basestring = str
-	long = int
-else:
-	_unicode = unicode
 
 class UseCachedCopyOfRemoteIndex(Exception):
 	# If the local copy is recent enough
@@ -166,9 +154,9 @@ class bindbapi(fakedbapi):
 			metadata_bytes = portage.xpak.tbz2(tbz2_path).get_data()
 			def getitem(k):
 				if k == "_mtime_":
-					return _unicode(st[stat.ST_MTIME])
+					return str(st[stat.ST_MTIME])
 				elif k == "SIZE":
-					return _unicode(st.st_size)
+					return str(st.st_size)
 				v = metadata_bytes.get(_unicode_encode(k,
 					encoding=_encodings['repo.content'],
 					errors='backslashreplace'))
@@ -470,7 +458,7 @@ class binarytree(object):
 		# sanity check
 		for atom in (origcp, newcp):
 			if not isjustname(atom):
-				raise InvalidPackageName(_unicode(atom))
+				raise InvalidPackageName(str(atom))
 		mynewcat = catsplit(newcp)[0]
 		origmatches=self.dbapi.cp_list(origcp)
 		moves = 0
@@ -494,7 +482,7 @@ class binarytree(object):
 			if not isvalidatom(newcp, eapi=mycpv.eapi):
 				continue
 
-			mynewcpv = mycpv.replace(mycpv_cp, _unicode(newcp), 1)
+			mynewcpv = mycpv.replace(mycpv_cp, str(newcp), 1)
 			myoldpkg = catsplit(mycpv)[1]
 			mynewpkg = catsplit(mynewcpv)[1]
 
@@ -727,12 +715,12 @@ class binarytree(object):
 						match = None
 						for d in possibilities:
 							try:
-								if long(d["_mtime_"]) != s[stat.ST_MTIME]:
+								if int(d["_mtime_"]) != s[stat.ST_MTIME]:
 									continue
 							except (KeyError, ValueError):
 								continue
 							try:
-								if long(d["SIZE"]) != long(s.st_size):
+								if int(d["SIZE"]) != int(s.st_size):
 									continue
 							except (KeyError, ValueError):
 								continue
@@ -819,7 +807,7 @@ class binarytree(object):
 
 					if pkg_metadata.get("BUILD_ID"):
 						try:
-							build_id = long(pkg_metadata["BUILD_ID"])
+							build_id = int(pkg_metadata["BUILD_ID"])
 						except ValueError:
 							writemsg(_("!!! Binary package has "
 								"invalid BUILD_ID: '%s'\n") %
@@ -849,8 +837,8 @@ class binarytree(object):
 							noiselevel=-1)
 						continue
 					if build_id is not None:
-						pkg_metadata["BUILD_ID"] = _unicode(build_id)
-					pkg_metadata["SIZE"] = _unicode(s.st_size)
+						pkg_metadata["BUILD_ID"] = str(build_id)
+					pkg_metadata["SIZE"] = str(s.st_size)
 					# Discard items used only for validation above.
 					pkg_metadata.pop("CATEGORY")
 					pkg_metadata.pop("PF")
@@ -864,13 +852,13 @@ class binarytree(object):
 						pkgindex._pkg_slot_dict())
 					if d:
 						try:
-							if long(d["_mtime_"]) != s[stat.ST_MTIME]:
+							if int(d["_mtime_"]) != s[stat.ST_MTIME]:
 								d.clear()
 						except (KeyError, ValueError):
 							d.clear()
 					if d:
 						try:
-							if long(d["SIZE"]) != long(s.st_size):
+							if int(d["SIZE"]) != int(s.st_size):
 								d.clear()
 						except (KeyError, ValueError):
 							d.clear()
@@ -1096,12 +1084,12 @@ class binarytree(object):
 				writemsg(_("\n\n!!! Error fetching binhost package" \
 					" info from '%s'\n") % _hide_url_passwd(base_url))
 				# With Python 2, the EnvironmentError message may
-				# contain bytes or unicode, so use _unicode to ensure
+				# contain bytes or unicode, so use str to ensure
 				# safety with all locales (bug #532784).
 				try:
-					error_msg = _unicode(e)
+					error_msg = str(e)
 				except UnicodeDecodeError as uerror:
-					error_msg = _unicode(uerror.object,
+					error_msg = str(uerror.object,
 						encoding='utf_8', errors='replace')
 				writemsg("!!! %s\n\n" % error_msg)
 				del e
@@ -1244,7 +1232,7 @@ class binarytree(object):
 				# attributes, so that we can later distinguish that it
 				# is identical to its remote counterpart.
 				build_id = self._parse_build_id(basename)
-				metadata["BUILD_ID"] = _unicode(build_id)
+				metadata["BUILD_ID"] = str(build_id)
 				cpv = _pkg_str(cpv, metadata=metadata,
 					settings=self.settings, db=self.dbapi)
 				binpkg = portage.xpak.tbz2(full_path)
@@ -1296,9 +1284,9 @@ class binarytree(object):
 		binary_metadata = portage.xpak.tbz2(filename).get_data()
 		for k in keys:
 			if k == "_mtime_":
-				metadata[k] = _unicode(st[stat.ST_MTIME])
+				metadata[k] = str(st[stat.ST_MTIME])
 			elif k == "SIZE":
-				metadata[k] = _unicode(st.st_size)
+				metadata[k] = str(st.st_size)
 			else:
 				v = binary_metadata.get(_unicode_encode(k))
 				if v is None:
@@ -1356,7 +1344,7 @@ class binarytree(object):
 		contents = codecs.getwriter(_encodings['repo.content'])(io.BytesIO())
 		pkgindex.write(contents)
 		contents = contents.getvalue()
-		atime = mtime = long(pkgindex.header["TIMESTAMP"])
+		atime = mtime = int(pkgindex.header["TIMESTAMP"])
 		output_files = [(atomic_ofstream(self._pkgindex_file, mode="wb"),
 			self._pkgindex_file, None)]
 
@@ -1391,8 +1379,8 @@ class binarytree(object):
 
 		d["CPV"] = cpv
 		st = os.lstat(pkg_path)
-		d["_mtime_"] = _unicode(st[stat.ST_MTIME])
-		d["SIZE"] = _unicode(st.st_size)
+		d["_mtime_"] = str(st[stat.ST_MTIME])
+		d["SIZE"] = str(st.st_size)
 
 		rel_path = pkg_path[len(self.pkgdir)+1:]
 		# record location if it's non-default
@@ -1471,7 +1459,7 @@ class binarytree(object):
 		"""
 		if not (self.settings.profile_path and
 			"IUSE_IMPLICIT" in self.settings):
-			header.setdefault("VERSION", _unicode(self._pkgindex_version))
+			header.setdefault("VERSION", str(self._pkgindex_version))
 			return
 
 		portdir = normalize_path(os.path.realpath(self.settings["PORTDIR"]))
@@ -1482,7 +1470,7 @@ class binarytree(object):
 			if profile_path.startswith(profiles_base):
 				profile_path = profile_path[len(profiles_base):]
 			header["PROFILE"] = profile_path
-		header["VERSION"] = _unicode(self._pkgindex_version)
+		header["VERSION"] = str(self._pkgindex_version)
 		base_uri = self.settings.get("PORTAGE_BINHOST_HEADER_URI")
 		if base_uri:
 			header["URI"] = base_uri
@@ -1657,7 +1645,7 @@ class binarytree(object):
 		if hyphen != -1:
 			build_id = filename[hyphen+1:-suffixlen]
 		try:
-			build_id = long(build_id)
+			build_id = int(build_id)
 		except ValueError:
 			pass
 		return build_id
