@@ -1,8 +1,6 @@
 # Copyright 2010-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import unicode_literals
-
 __all__ = ['dep_check', 'dep_eval', 'dep_wordreduce', 'dep_zapdeps']
 
 import collections
@@ -510,7 +508,7 @@ def dep_zapdeps(unreduced, reduced, myroot, use_binaries=0, trees=None,
 		else:
 			new_slot_count = 0
 			for slot_atom, avail_pkg in slot_map.items():
-				if graph_interface.want_update_pkg(parent, avail_pkg):
+				if parent is not None and graph_interface.want_update_pkg(parent, avail_pkg):
 					want_update = True
 				if (not slot_atom.cp.startswith("virtual/")
 					and not graph_db.match_pkgs(slot_atom)):
