@@ -1,4 +1,4 @@
-# Copyright 1998-2015 Gentoo Foundation
+# Copyright 1998-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 from __future__ import division
@@ -234,7 +234,7 @@ def nc_len(mystr):
 	tmp = re.sub(esc_seq + "^m]+m", "", mystr);
 	return len(tmp)
 
-_legal_terms_re = re.compile(r'^(xterm|xterm-color|Eterm|aterm|rxvt|screen|kterm|rxvt-unicode|gnome|interix|tmux|st-256color|alacritty)')
+_legal_terms_re = re.compile(r'^(xterm|xterm-color|Eterm|aterm|rxvt|screen|kterm|rxvt-unicode|gnome|interix|tmux|st-256color|alacritty|konsole)')
 _disable_xtermTitle = None
 _max_xtermTitle_len = 253
 
@@ -256,9 +256,7 @@ def xtermTitle(mystr, raw=False):
 		# avoid potential UnicodeEncodeError
 		mystr = _unicode_encode(mystr,
 			encoding=_encodings['stdio'], errors='backslashreplace')
-		f = sys.stderr
-		if sys.hexversion >= 0x3000000:
-			f = f.buffer
+		f = sys.stderr.buffer
 		f.write(mystr)
 		f.flush()
 
@@ -398,8 +396,7 @@ class ConsoleStyleFile(object):
 		if f in (sys.stdout, sys.stderr):
 			s = _unicode_encode(s,
 				encoding=_encodings['stdio'], errors='backslashreplace')
-			if sys.hexversion >= 0x3000000:
-				f = f.buffer
+			f = f.buffer
 		f.write(s)
 
 	def writelines(self, lines):
