@@ -1,5 +1,5 @@
 # portage.py -- core Portage functionality
-# Copyright 1998-2019 Gentoo Authors
+# Copyright 1998-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 
@@ -40,9 +40,6 @@ try:
 except ImportError:
 	max_fd_limit = 256
 
-if sys.hexversion >= 0x3000000:
-	# pylint: disable=W0622
-	basestring = str
 
 # Support PEP 446 for Python >=3.4
 try:
@@ -110,7 +107,7 @@ def sanitize_fds():
 	if _set_inheritable is not None:
 
 		whitelist = frozenset([
-			sys.__stdin__.fileno(),
+			portage._get_stdin().fileno(),
 			sys.__stdout__.fileno(),
 			sys.__stderr__.fileno(),
 		])
@@ -201,10 +198,7 @@ def run_exitfuncs():
 			exc_info = sys.exc_info()
 
 	if exc_info is not None:
-		if sys.hexversion >= 0x3000000:
-			raise exc_info[0](exc_info[1]).with_traceback(exc_info[2])
-		else:
-			exec("raise exc_info[0], exc_info[1], exc_info[2]")
+		raise exc_info[0](exc_info[1]).with_traceback(exc_info[2])
 
 atexit.register(run_exitfuncs)
 
@@ -229,7 +223,7 @@ def cleanup():
 def spawn(mycommand, env=None, opt_name=None, fd_pipes=None, returnpid=False,
           uid=None, gid=None, groups=None, umask=None, cwd=None, logfile=None,
           path_lookup=True, pre_exec=None,
-          close_fds=(sys.version_info < (3, 4)), unshare_net=False,
+          close_fds=False, unshare_net=False,
           unshare_ipc=False, unshare_mount=False, unshare_pid=False,
 	  cgroup=None):
 	"""
@@ -287,20 +281,11 @@ def spawn(mycommand, env=None, opt_name=None, fd_pipes=None, returnpid=False,
 	"""
 
 	# mycommand is either a str or a list
-	if isinstance(mycommand, basestring):
+	if isinstance(mycommand, str):
 		mycommand = mycommand.split()
 
 	env = os.environ if env is None else env
 
-	if sys.hexversion < 0x3000000:
-		# Avoid a potential UnicodeEncodeError from os.execve().
-		env_bytes = {}
-		for k, v in env.items():
-			env_bytes[_unicode_encode(k, encoding=_encodings['content'])] = \
-				_unicode_encode(v, encoding=_encodings['content'])
-		env = env_bytes
-		del env_bytes
-
 	# If an absolute path to an executable file isn't given
 	# search for it unless we've been told not to.
 	binary = mycommand[0]
@@ -967,7 +952,7 @@ def find_binary(binary):
 	@return: full path to binary or None if the binary could not be located.
 	"""
 	paths = os.environ.get("PATH", "")
-	if sys.hexversion >= 0x3000000 and isinstance(binary, bytes):
+	if isinstance(binary, bytes):
 		# return bytes when input is bytes
 		paths = paths.encode(sys.getfilesystemencoding(), 'surrogateescape')
 		paths = paths.split(b':')
