@@ -34,9 +34,6 @@ try:
 except ImportError:
 	cnf_path_repoman = None
 
-if sys.hexversion >= 0x3000000:
-	# pylint: disable=W0622
-	basestring = str
 
 class ResolverPlayground(object):
 	"""
@@ -91,6 +88,7 @@ class ResolverPlayground(object):
 				"chgrp",
 				"chmod",
 				"chown",
+				"comm",
 				"cp",
 				"egrep",
 				"env",
@@ -410,7 +408,7 @@ class ResolverPlayground(object):
 
 			for eclass_name, eclass_content in eclasses.items():
 				with open(os.path.join(eclass_dir, "{}.eclass".format(eclass_name)), 'wt') as f:
-					if isinstance(eclass_content, basestring):
+					if isinstance(eclass_content, str):
 						eclass_content = [eclass_content]
 					for line in eclass_content:
 						f.write("{}\n".format(line))
@@ -694,7 +692,7 @@ class ResolverPlaygroundTestCase(object):
 					if expected:
 						new_expected = []
 						for obj in expected:
-							if isinstance(obj, basestring):
+							if isinstance(obj, str):
 								if obj[:1] == "!":
 									new_expected.append(obj)
 									continue
@@ -719,7 +717,7 @@ class ResolverPlaygroundTestCase(object):
 					while got_stack and expected_stack:
 						got_token = got_stack.pop()
 						expected_obj = expected_stack.pop()
-						if isinstance(expected_obj, basestring):
+						if isinstance(expected_obj, str):
 							new_expected.append(expected_obj)
 							if got_token == expected_obj:
 								continue
